==> provider_software_3.3.2.tar.gz: provider_software_3.3.2/lib/biocase/wrapper/dbmod/dbmod_psycopg2.py <==
# -*- coding: utf8 -*-
'''DB MODULE - PSYCO-POSTGRESQL
*******************************
***  DB MODULE - PSYCO-POSTGRESQL
*******************************
$RCSfile: dbmod_psycopg.py,v $
$Revision: 1231 $
$Author: j.holetschek $
$Date: 2012-11-21 15:12:34 +0100 (Mi, 21. Nov 2012) $

The biocase.wrapper database module to access PostgreSQL databases.
You will need the psycopg module to connect to a PostgreSQL DB.
'''

from string								import join
from biocase.wrapper.errorclasses 		import *
from biocase.wrapper.sql.base 			import sqlBase
from biocase.wrapper.dbmod.base_dbmod   import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod.postgres")


#############################################
#
# CUSTOMIZATION for PostgreSQL
#
# OVERLOAD BASE CLASSES AND OTHER METHODS
#
#############################################

# uses inherited ANSI SQL apart from the following.
sqlBase.templates['attribute'] = '"#1"."#2"'
sqlBase.templates['table'] = '"#1"'
sqlBase.binaryCOP['like'] = "ILIKE"
sqlBase.templates['select-limit-offset'] = 'SELECT DISTINCT #1 FROM #2 LIMIT #3 offset #4'
		

# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
class DBmodule(DBBasemodule):
	__version__ = '0.4 using psycopg ?'
	__dbmod__	= u'Psycopg2 DB module'
	
	# _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
	def __init__(self, psfObj):
		# setting the psfObj reference to self.psfObj
		# call createDBconnection method
		DBBasemodule.__init__(self, psfObj)
		# dont use parameters but integrate all parameters into SQL strings:
		self.trans.integrateParametersInSQLString()
		# set unicode encoding to true
		#c = self.conn.cursor()
		#c.execute("set client_encoding to %s" %(self.psfObj.encoding))
		#c = None


	# _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
	def createDBconnection(self):
		try:
			import psycopg2
		except:
			raise DbModuleMissingError('psycopg')
		self.__class__.__version__ = self.__class__.__version__[:-1]+psycopg2.__version__
		try:
			if len(self.psfObj.password) > 0:
				loginParas = "host=%s user=%s password=%s dbname=%s" % (self.psfObj.dbIP, self.psfObj.user, self.psfObj.password, self.psfObj.database )
				return psycopg2.connect(loginParas)
			else:
				loginParas = "host=%s user=%s dbname=%s" % (self.psfObj.dbIP, self.psfObj.user, self.psfObj.database )
				return psycopg2.connect(loginParas)
		except:
			raise ConnectionError()
    
	def getTables(self):
		#log.error("")
		if self.conn.server_version < 80000:
			return None

		
		tables = []
		self.c = self.conn.cursor()
		self.c.execute("select table_name from information_schema.tables WHERE table_schema='public' AND (table_type='BASE TABLE' or table_type='VIEW')")
		for t in self.c.fetchall():
			tables.append(str(t[0]))

		self.c.close()
		return tables

	def getColumns(self, table):
		#log.error(str(self.conn.server_version))		
		if self.conn.server_version < 80000:
			return None

		
		columns = []
		self.c = self.conn.cursor()
		self.c.execute("SELECT column_name FROM information_schema.columns WHERE table_name = '" + table + "'")
		for t in self.c.fetchall():
			columns.append(str(t[0]))

		self.c.close()
		return columns
		
	def hasMetaInfo(self):
		try:
			if self.conn.server_version < 80000:
				return False
			return True
		except:
			return False

==> provider_software_3.4.2.tar.gz: provider_software_3.4.2/lib/biocase/wrapper/dbmod/dbmod_psycopg2.py <==
# -*- coding: utf8 -*-
'''DB MODULE - PSYCO-POSTGRESQL
*******************************
***  DB MODULE - PSYCO-POSTGRESQL
*******************************
$RCSfile: dbmod_psycopg.py,v $
$Revision: 1284 $
$Author: j.holetschek $
$Date: 2013-03-07 13:52:20 +0100 (Do, 07. Mär 2013) $

The biocase.wrapper database module to access PostgreSQL databases.
You will need the psycopg module to connect to a PostgreSQL DB.
'''

from biocase.wrapper.errorclasses 		import DbModuleMissingError, ConnectionError
from biocase.wrapper.sql.base 			import sqlBase
from biocase.wrapper.dbmod.base_dbmod   import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod.postgres")


#############################################
#
# CUSTOMIZATION for PostgreSQL
#
# OVERLOAD BASE CLASSES AND OTHER METHODS
#
#############################################

# uses inherited ANSI SQL apart from the following.
sqlBase.templates['attribute'] = '"#1"."#2"'
sqlBase.templates['table'] = '"#1"'
sqlBase.binaryCOP['like'] = "ILIKE"
sqlBase.templates['select-limit-offset'] = 'SELECT DISTINCT #1 FROM #2 LIMIT #3 offset #4'
sqlBase.templates['count-distinct'] = 'COUNT(DISTINCT #1)'


# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
# ---------------------------------------------------------------------------------
class DBmodule(DBBasemodule):
	__version__ = '0.4 using psycopg ?'
	__dbmod__	 = u'Psycopg2 DB module'

	# _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
	def __init__(self, psfObj):
		# setting the psfObj reference to self.psfObj
		# call createDBconnection method
		DBBasemodule.__init__(self, psfObj)
		# dont use parameters but integrate all parameters into SQL strings:
		self.trans.integrateParametersInSQLString()

	# _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
	def createDBconnection(self):
		try:
			import psycopg2
		except:
			raise DbModuleMissingError('psycopg')
		self.__class__.__version__ = self.__class__.__version__[:-1] + psycopg2.__version__
		try:
			if len(self.psfObj.password) > 0:
				loginParas = "host=%s user=%s password=%s dbname=%s" % (self.psfObj.dbIP, self.psfObj.user, self.psfObj.password, self.psfObj.database)
				return psycopg2.connect(loginParas)
			else:
				loginParas = "host=%s user=%s dbname=%s" % (self.psfObj.dbIP, self.psfObj.user, self.psfObj.database)
				return psycopg2.connect(loginParas)
		except:
			raise ConnectionError()

	def execSQL(self, sql, paras=None):
		res = []
		for rec in DBBasemodule.execSQL(self, sql, paras):
			res += [tuple([unicode(column, self.psfObj.encoding) if isinstance(column, str) else column for column in rec])]
		return res

	def getTables(self):
		#log.error("")
		if self.conn.server_version < 80000:
			return None

		tables = []
		self.c = self.conn.cursor()
		self.c.execute("select table_name from information_schema.tables WHERE table_schema='public' AND (table_type='BASE TABLE' or table_type='VIEW')")
		for t in self.c.fetchall():
			tables.append(str(t[0]))

		self.c.close()
		return tables

	def getColumns(self, table):
		#log.error(str(self.conn.server_version))
		if self.conn.server_version < 80000:
			return None

		columns = []
		self.c = self.conn.cursor()
		self.c.execute("SELECT column_name FROM information_schema.columns WHERE table_name = '" + table + "'")
		for t in self.c.fetchall():
			columns.append(str(t[0]))

		self.c.close()
		return columns

	def hasMetaInfo(self):
		try:
			if self.conn.server_version < 80000:
				return False
			return True
		except:
			return False
